geowatch.tasks.fusion.methods.noop\_model module
================================================

.. automodule:: geowatch.tasks.fusion.methods.noop_model
   :members:
   :undoc-members:
   :show-inheritance:
